

HPD-20 Editor
=============

Synopsis
--------

Program to copy kits around (shared in internet?), modify scales for melodic stuff
create chains, appl modifications on pan, volume, sweep etc.

The HPD-20 can not be edited via MIDI.
This small program will need backups that you create in the SYS-USB Memory menu to work with. Sorry, there is no other way to make it more interactive.
On the other hand it will help you to manage and exchange your kits with other people, create easily melody based kits
and last but not least to print your settings on some paper so you will have them ready i.e. for live performances and you just forgot some important setting.


Roadmap
-------

- (/) read memory dump (BKUP-???.HS0)

- (/) save all kits into folder

- (/) load single kit from folder

- (/) patch simple scales with modes on instrument A

- (/) patch scales with different layouts (across, around, etc.)

- (/) retrieve note for melodic pads (instruments 348-433

- (x) fetch basic information from kit and pad

- (x) patch scales on instrument B

- (x) copy kits around

- (x) UI the whole stuff (tkinter?)

- (x) publish on various musician sites

Macro operations todo
---------------------

- patch scales

- pan over a pad-set

- swap left right (M1 <-> M2, M3 <-> M4, S1 <-> S8 etc...)


Generic todo
------------

get more pitches from some instruments that are for now presumed in C (i.e. Roto Toms, Cowbell)

add unit-tests for the inplace memory manipulations

